@@ -27,21 +27,42 @@ from xp.utils.dependencies import ServiceContainer
 )
 @click.version_option()
 @click.pass_context
-def cli(ctx: click.Context, service_container: ServiceContainer | None = None) -> None:
+def cli(ctx: click.Context) -> None:
     """XP CLI tool for remote console bus operations"""
-    logging.basicConfig(level=logging.DEBUG)
+    # Configure logging with thread information
+    log_format = "%(asctime)s - [%(threadName)s-%(thread)d] - %(levelname)s - %(name)s - %(message)s"
+    date_format = "%H:%M:%S"
+
+    # Force format on root logger and all handlers
+    formatter = logging.Formatter(log_format, datefmt=date_format)
+    root_logger = logging.getLogger()
+    root_logger.setLevel(logging.DEBUG)
+
+    # Update all existing handlers or create new one
+    if root_logger.handlers:
+        for handler in root_logger.handlers:
+            handler.setFormatter(formatter)
+    else:
+        handler = logging.StreamHandler()
+        handler.setFormatter(formatter)
+        root_logger.addHandler(handler)
     # Suppress pyhap.hap_protocol logs
     logging.getLogger("pyhap.hap_protocol").setLevel(logging.WARNING)
     logging.getLogger("pyhap.hap_handler").setLevel(logging.WARNING)
     # logging.getLogger('pyhap.accessory_driver').setLevel(logging.WARNING)
 
+    # Ensure xp module logs at DEBUG level
+    logging.getLogger("xp").setLevel(logging.DEBUG)
+    logging.getLogger("xp.services.homekit.homekit_service").setLevel(logging.INFO)
+    # logging.getLogger("xp.services.protocol.telegram_protocol").setLevel(logging.INFO)
+    logging.getLogger("pyhap").setLevel(logging.DEBUG)
+    logging.getLogger("bubus").setLevel(logging.DEBUG)
+
     # Initialize the service container and store it in the context
     ctx.ensure_object(dict)
-    # Only create a new container if one doesn't already exist (for testing)
+    # Only create a new container if one wasn't provided (e.g., for testing)
     if "container" not in ctx.obj:
-        if service_container is None:
-            service_container = ServiceContainer()
-        ctx.obj["container"] = service_container
+        ctx.obj["container"] = ServiceContainer()
 
 
 # Register all command groups
