@@ -1,9 +1,9 @@
 """Connection layer for XP CLI tool"""
 
-from .exceptions import (
-    XPError,
+from xp.connection.exceptions import (
     ProtocolError,
     ValidationError,
+    XPError,
 )
 
 __all__ = [
