@@ -1,16 +1,16 @@
 """Log file parsing service for console bus communication logs."""
 
 import re
-from pathlib import Path
-from typing import List, Optional, Dict, Any
 from datetime import datetime
+from pathlib import Path
+from typing import Any, Dict, List, Optional
 
-from ..models.log_entry import LogEntry
-from ..services.telegram_service import TelegramService, TelegramParsingError
-from ..utils.time_utils import (
-    parse_log_timestamp,
+from xp.models.log_entry import LogEntry
+from xp.services.telegram.telegram_service import TelegramParsingError, TelegramService
+from xp.utils.time_utils import (
     TimeParsingError,
     calculate_duration_ms,
+    parse_log_timestamp,
 )
 
 
@@ -33,14 +33,14 @@ class LogFileService:
         r"^(\d{2}:\d{2}:\d{2},\d{3})\s+\[([TR]X)\]\s+(<[^>]+>)\s*$"
     )
 
-    def __init__(self, telegram_service: Optional[TelegramService] = None):
+    def __init__(self, telegram_service: TelegramService):
         """
         Initialize the log file service
 
         Args:
-            telegram_service: Optional telegram service for parsing telegrams
+            telegram_service: Telegram service for parsing telegrams
         """
-        self.telegram_service = telegram_service or TelegramService()
+        self.telegram_service = telegram_service
 
     def parse_log_file(
         self, file_path: str, base_date: Optional[datetime] = None
