@@ -3,6 +3,8 @@
 import punq
 from bubus import EventBus
 from twisted.internet import asyncioreactor
+from twisted.internet.interfaces import IConnector
+from twisted.internet.posixbase import PosixReactorBase
 
 from xp.models import ConbusClientConfig
 from xp.models.homekit.homekit_config import HomekitConfig
@@ -26,8 +28,12 @@ from xp.services.conbus.conbus_receive_service import ConbusReceiveService
 from xp.services.conbus.conbus_scan_service import ConbusScanService
 from xp.services.conbus.conbus_service import ConbusService
 from xp.services.homekit.homekit_cache_service import HomeKitCacheService
-from xp.services.homekit.homekit_module_factory import HomekitModuleFactory
+from xp.services.homekit.homekit_conbus_service import HomeKitConbusService
+from xp.services.homekit.homekit_dimminglight_service import HomeKitDimmingLightService
+from xp.services.homekit.homekit_hap_service import HomekitHapService
+from xp.services.homekit.homekit_lightbulb_service import HomeKitLightbulbService
 from xp.services.homekit.homekit_module_service import HomekitModuleService
+from xp.services.homekit.homekit_outlet_service import HomeKitOutletService
 from xp.services.homekit.homekit_service import HomeKitService
 from xp.services.log_file_service import LogFileService
 from xp.services.module_type_service import ModuleTypeService
@@ -289,6 +295,13 @@ class ServiceContainer:
             scope=punq.Scope.singleton,
         )
 
+        # Create event bus
+        self.container.register(
+            EventBus,
+            factory=lambda: EventBus(max_history_size=500),
+            scope=punq.Scope.singleton,
+        )
+
         # HomeKit conson config
         self.container.register(
             HomekitConfig,
@@ -297,15 +310,11 @@ class ServiceContainer:
         )
 
         self.container.register(
-            HomekitModuleFactory,
-            factory=lambda: HomekitModuleFactory(
+            HomekitHapService,
+            factory=lambda: HomekitHapService(
                 homekit_config=self.container.resolve(HomekitConfig),
                 module_service=self.container.resolve(HomekitModuleService),
-                output_service=self.container.resolve(ConbusOutputService),
-                telegram_output_service=self.container.resolve(TelegramOutputService),
-                datapoint_service=self.container.resolve(ConbusDatapointService),
-                cache_service=self.container.resolve(HomeKitCacheService),
-                lightlevel_service=self.container.resolve(ConbusLightlevelService),
+                event_bus=self.container.resolve(EventBus),
             ),
             scope=punq.Scope.singleton,
         )
@@ -344,13 +353,6 @@ class ServiceContainer:
             scope=punq.Scope.singleton,
         )
 
-        # Create event bus
-        self.container.register(
-            EventBus,
-            factory=lambda: EventBus(max_history_size=50),
-            scope=punq.Scope.singleton,
-        )
-
         # Create protocol
         self.container.register(
             TelegramProtocol,
@@ -360,21 +362,79 @@ class ServiceContainer:
             scope=punq.Scope.singleton,
         )
 
+        self.container.register(
+            IConnector,
+            factory=lambda: reactor,
+            scope=punq.Scope.singleton,
+        )
+
         self.container.register(
             TelegramFactory,
             factory=lambda: TelegramFactory(
                 event_bus=self.container.resolve(EventBus),
                 telegram_protocol=self.container.resolve(TelegramProtocol),
+                connector=self.container.resolve(IConnector),
             ),
             scope=punq.Scope.singleton,
         )
 
+        self.container.register(
+            PosixReactorBase,
+            factory=lambda: reactor,
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            HomeKitLightbulbService,
+            factory=lambda: HomeKitLightbulbService(
+                event_bus=self.container.resolve(EventBus),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            HomeKitOutletService,
+            factory=lambda: HomeKitOutletService(
+                event_bus=self.container.resolve(EventBus),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            HomeKitDimmingLightService,
+            factory=lambda: HomeKitDimmingLightService(
+                event_bus=self.container.resolve(EventBus),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            HomeKitConbusService,
+            factory=lambda: HomeKitConbusService(
+                event_bus=self.container.resolve(EventBus),
+                telegram_protocol=self.container.resolve(TelegramProtocol),
+            ),
+            scope=punq.Scope.singleton,
+        )
+
+        self.container.register(
+            TelegramService,
+            factory=TelegramService,
+            scope=punq.Scope.singleton,
+        )
+
         self.container.register(
             HomeKitService,
             factory=lambda: HomeKitService(
                 event_bus=self.container.resolve(EventBus),
                 telegram_factory=self.container.resolve(TelegramFactory),
-                reactor=reactor,
+                reactor=self.container.resolve(PosixReactorBase),
+                lightbulb_service=self.container.resolve(HomeKitLightbulbService),
+                outlet_service=self.container.resolve(HomeKitOutletService),
+                dimminglight_service=self.container.resolve(HomeKitDimmingLightService),
+                conbus_service=self.container.resolve(HomeKitConbusService),
+                module_factory=self.container.resolve(HomekitHapService),
+                telegram_service=self.container.resolve(TelegramService),
             ),
             scope=punq.Scope.singleton,
         )
