@@ -5,8 +5,8 @@ from typing import List
 import pytest
 import yaml
 
-from xp.models.homekit_conson_config import ConsonModuleConfig
-from xp.services.homekit_config_validator import ConfigValidationService
+from xp.models.homekit.homekit_conson_config import ConsonModuleConfig
+from xp.services.homekit.homekit_config_validator import ConfigValidationService
 
 
 class TestHomekitConfigIntegration:
@@ -230,11 +230,6 @@ class TestHomekitConfigIntegration:
         finally:
             self.cleanup_temp_files(conson_file, homekit_file)
 
-    def test_missing_files_integration(self):
-        """Test behavior when configuration files are missing."""
-        with pytest.raises(FileNotFoundError):
-            ConfigValidationService("nonexistent_conson.yml", "nonexistent_homekit.yml")
-
     def test_malformed_yaml_integration(self):
         """Test behavior with malformed YAML files."""
         # Create malformed conson YAML
