@@ -1,13 +1,14 @@
 """Tests for LogEntry model"""
 
 from datetime import datetime
-from xp.models.log_entry import LogEntry
-from xp.models.event_telegram import EventTelegram
+
 from xp.models import EventType
-from xp.models.system_telegram import SystemTelegram
-from xp.models.datapoint_type import DataPointType
-from xp.models.system_function import SystemFunction
-from xp.models.reply_telegram import ReplyTelegram
+from xp.models.log_entry import LogEntry
+from xp.models.telegram.datapoint_type import DataPointType
+from xp.models.telegram.event_telegram import EventTelegram
+from xp.models.telegram.reply_telegram import ReplyTelegram
+from xp.models.telegram.system_function import SystemFunction
+from xp.models.telegram.system_telegram import SystemTelegram
 
 
 class TestLogEntry:
