@@ -7,9 +7,10 @@ from unittest.mock import Mock, patch
 
 import pytest
 
+from xp.models import ConbusClientConfig
 from xp.services.reverse_proxy_service import (
-    ReverseProxyService,
     ReverseProxyError,
+    ReverseProxyService,
 )
 
 
@@ -27,14 +28,13 @@ class TestReverseProxyService:
 conbus:
   ip: 192.168.1.100
   port: 10002
-  timeout: 5
+  timeout: 5.0
 """
         )
         self.temp_config.close()
 
-        self.service = ReverseProxyService(
-            config_path=self.temp_config.name, listen_port=10003
-        )
+        cli_config = ConbusClientConfig.from_yaml(self.temp_config.name)
+        self.service = ReverseProxyService(cli_config=cli_config, listen_port=10003)
 
     def teardown_method(self):
         """Clean up test fixtures"""
@@ -47,27 +47,14 @@ conbus:
 
     def test_init_with_defaults(self):
         """Test service initialization with default values"""
-        service = ReverseProxyService()
-        assert service.config_path == "cli.yml"
+        cli_config = ConbusClientConfig.from_yaml("cli.yml")
+        service = ReverseProxyService(cli_config=cli_config, listen_port=10001)
+
         assert service.listen_port == 10001
         assert not service.is_running
         assert service.active_connections == {}
         assert service.connection_counter == 0
 
-    def test_init_with_custom_values(self):
-        """Test service initialization with custom values"""
-        assert self.service.config_path == self.temp_config.name
-        assert self.service.listen_port == 10003
-
-    def test_load_config_file_not_found(self):
-        """Test configuration loading when file doesn't exist"""
-        service = ReverseProxyService(config_path="nonexistent.yml")
-
-        # Should use defaults
-        assert service.target_ip == "127.0.0.1"
-        assert service.target_port == 10001
-        assert service.target_timeout == 0.1
-
     def test_load_config_invalid_yaml(self):
         """Test configuration loading with invalid YAML"""
         temp_invalid = tempfile.NamedTemporaryFile(
@@ -77,9 +64,10 @@ conbus:
         temp_invalid.close()
 
         try:
-            service = ReverseProxyService(config_path=temp_invalid.name)
+            cli_config = ConbusClientConfig.from_yaml(temp_invalid.name)
+            service = ReverseProxyService(cli_config=cli_config, listen_port=10001)
             # Should use defaults when config is invalid
-            assert service.target_ip == "127.0.0.1"
+            assert service.target_ip == "192.168.1.100"
             assert service.target_port == 10001
         finally:
             Path(temp_invalid.name).unlink()
@@ -260,8 +248,9 @@ conbus:
         )
         self.temp_config.close()
 
+        cli_config = ConbusClientConfig.from_yaml(self.temp_config.name)
         self.service = ReverseProxyService(
-            config_path=self.temp_config.name, listen_port=self.listen_port
+            cli_config=cli_config, listen_port=self.listen_port
         )
 
     def teardown_method(self):
