@@ -1,16 +1,19 @@
-from xp.models.homekit_config import (
-    HomekitConfig,
-    HomekitAccessoryConfig,
-    RoomConfig,
+from xp.models.homekit.homekit_config import (
     BridgeConfig,
+    HomekitAccessoryConfig,
+    HomekitConfig,
     NetworkConfig,
+    RoomConfig,
 )
-from xp.models.homekit_conson_config import ConsonModuleConfig, ConsonModuleListConfig
-from xp.services.homekit_config_validator import (
-    HomekitConfigValidator,
+from xp.models.homekit.homekit_conson_config import (
+    ConsonModuleConfig,
+    ConsonModuleListConfig,
+)
+from xp.services.homekit.homekit_config_validator import (
     CrossReferenceValidator,
+    HomekitConfigValidator,
 )
-from xp.services.homekit_conson_config_service import ConsonConfigValidator
+from xp.services.homekit.homekit_conson_validator import ConsonConfigValidator
 
 
 class TestHomekitConfigValidator:
